@@ -325,9 +325,6 @@ class CanvasEnrollment(models.Model):
     last_activity_at = models.DateTimeField(null=True)
     limit_privileges_to_course_section = models.NullBooleanField()
 
-    def get_course_url(self, html_url):
-        return re.sub(r'/users/\d+$', '', html_url)
-
     def __init__(self, *args, **kwargs):
         data = kwargs.get("data")
         if data is None:
@@ -339,6 +336,7 @@ class CanvasEnrollment(models.Model):
         self.section_id = data["course_section_id"]
         self.sis_course_id = data.get("sis_course_id")
         self.sis_section_id = data.get("sis_section_id")
+        self.sis_user_id = data.get("sis_user_id")
         self.role = data["type"]
         self.status = data["enrollment_state"]
         self.html_url = data["html_url"]
@@ -356,7 +354,6 @@ class CanvasEnrollment(models.Model):
             self.name = user_data.get("name")
             self.sortable_name = user_data.get("sortable_name")
             self.login_id = user_data.get("login_id")
-            self.sis_user_id = user_data.get("sis_user_id")
 
         if "grades" in data:
             gr_data = data["grades"]
@@ -372,6 +369,9 @@ class CanvasEnrollment(models.Model):
             self.override_grade = gr_data.get("override_grade")
             self.grade_html_url = gr_data.get("html_url")
 
+    def get_course_url(self, html_url):
+        return re.sub(r'/users/\d+$', '', html_url)
+
     def sws_course_id(self):
         return CanvasCourse(sis_course_id=self.sis_course_id).sws_course_id()
 
@@ -379,6 +379,12 @@ class CanvasEnrollment(models.Model):
         return CanvasSection(
             sis_section_id=self.sis_section_id).sws_section_id()
 
+    @staticmethod
+    def sis_import_role(role):
+        for base, name in CanvasEnrollment.ROLE_CHOICES:
+            if role.lower() == base.lower() or role.lower() == name.lower():
+                return name.lower()
+
     def json_data(self):
         return {"user_id": self.user_id,
                 "sis_user_id": self.sis_user_id,
@@ -529,7 +535,7 @@ class CanvasUser(models.Model):
         self.locale = data.get("locale")
         self.avatar_url = data.get("avatar_url")
         self.bio = data.get("bio")
-        if "last_login" in data and "last_login" is not None:
+        if "last_login" in data and data["last_login"] is not None:
             self.last_login = dateutil.parser.parse(data["last_login"])
         for enr_datum in data.get("enrollments", []):
             self.enrollments.append(CanvasEnrollment(data=enr_datum))
